.\"
.\" Sun Microsystems, Inc. gratefully acknowledges The Open Group for
.\" permission to reproduce portions of its copyrighted documentation.
.\" Original documentation from The Open Group can be obtained online at
.\" http://www.opengroup.org/bookstore/.
.\"
.\" The Institute of Electrical and Electronics Engineers and The Open
.\" Group, have given us permission to reprint portions of their
.\" documentation.
.\"
.\" In the following statement, the phrase ``this text'' refers to portions
.\" of the system documentation.
.\"
.\" Portions of this text are reprinted and reproduced in electronic form
.\" in the SunOS Reference Manual, from IEEE Std 1003.1, 2004 Edition,
.\" Standard for Information Technology -- Portable Operating System
.\" Interface (POSIX), The Open Group Base Specifications Issue 6,
.\" Copyright (C) 2001-2004 by the Institute of Electrical and Electronics
.\" Engineers, Inc and The Open Group.  In the event of any discrepancy
.\" between these versions and the original IEEE and The Open Group
.\" Standard, the original IEEE and The Open Group Standard is the referee
.\" document.  The original Standard can be obtained online at
.\" http://www.opengroup.org/unix/online.html.
.\"
.\" This notice shall appear on any product containing this material.
.\"
.\" The contents of this file are subject to the terms of the
.\" Common Development and Distribution License (the "License").
.\" You may not use this file except in compliance with the License.
.\"
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
.\" or http://www.opensolaris.org/os/licensing.
.\" See the License for the specific language governing permissions
.\" and limitations under the License.
.\"
.\" When distributing Covered Code, include this CDDL HEADER in each
.\" file and include the License file at usr/src/OPENSOLARIS.LICENSE.
.\" If applicable, add the following below this CDDL HEADER, with the
.\" fields enclosed by brackets "[]" replaced with your own identifying
.\" information: Portions Copyright [yyyy] [name of copyright owner]
.\"
.\"
.\" Copyright (c) 1992, X/Open Company Limited.  All Rights Reserved.
.\" Copyright (c) 2001, The IEEE and The Open Group.  All Rights Reserved.
.\" Portions Copyright (c) 2006, Sun Microsystems, Inc. All Rights Reserved.
.\"
.TH FMOD 3M "Jul 12, 2006" "SunOS 5.11" "Mathematical Library Functions"
.SH NAME
fmod, fmodf, fmodl \- floating-point remainder value function
.SH SYNOPSIS
.LP
.nf
c99 [ \fIflag\fR... ] \fIfile\fR... \fB-lm\fR [ \fIlibrary\fR... ]
#include <math.h>

\fBdouble\fR \fBfmod\fR(\fBdouble\fR \fIx\fR, \fBdouble\fR \fIy\fR);
.fi

.LP
.nf
\fBfloat\fR \fBfmodf\fR(\fBfloat\fR \fIx\fR, \fBfloat\fR \fIy\fR);
.fi

.LP
.nf
\fBlong double\fR \fBfmodl\fR(\fBlong double\fR \fIx\fR, \fBlong double\fR \fIy\fR);
.fi

.SH DESCRIPTION
.sp
.LP
These functions return the floating-point remainder of the division of \fIx\fR
by \fIy\fR.
.SH RETURN VALUES
.sp
.LP
These functions return the value \fIx\fR \(mi \fIi\fR * \fIy\fR, for some
integer \fIi\fR such that, if \fIy\fR is non-zero, the result has the same sign
as \fIx\fR and magnitude less than the magnitude of \fIy\fR.
.sp
.LP
If \fIx\fR or \fIy\fR is NaN, a NaN is returned.
.sp
.LP
If \fIy\fR is 0, a domain error occurs and a NaN is returned.
.sp
.LP
If \fIx\fR is infinite, a domain error occurs and a NaN is returned.
.sp
.LP
If \fIx\fR is \(+-0 and \fIy\fR is not 0, \(+-0 is returned.
.sp
.LP
If \fIx\fR is not infinite and \fIy\fR is \(+-Inf, \fIx\fR is returned.
.SH ERRORS
.sp
.LP
These functions will fail if:
.sp
.ne 2
.mk
.na
\fBDomain Error\fR
.ad
.RS 16n
.rt
The \fIx\fR argument is infinite or \fIy\fR is 0.
.sp
If the integer expression (\fBmath_errhandling\fR & \fBMATH_ERREXCEPT\fR) is
non-zero, the invalid floating-point exception is raised.
.RE

.SH USAGE
.sp
.LP
An application wanting to check for exceptions should call
\fBfeclearexcept\fR(\fBFE_ALL_EXCEPT\fR) before calling these functions. On
return, if \fBfetestexcept\fR(\fBFE_INVALID\fR | \fBFE_DIVBYZERO\fR |
\fBFE_OVERFLOW\fR | \fBFE_UNDERFLOW\fR) is non-zero, an exception has been
raised. An application should either examine the return value or check the
floating point exception flags to detect exceptions.
.SH ATTRIBUTES
.sp
.LP
See \fBattributes\fR(7) for descriptions of the following attributes:
.sp

.sp
.TS
tab(	) box;
cw(2.75i) |cw(2.75i)
lw(2.75i) |lw(2.75i)
.
ATTRIBUTE TYPE	ATTRIBUTE VALUE
_
Interface Stability	Standard
_
MT-Level	MT-Safe
.TE

.SH SEE ALSO
.sp
.LP
.BR math.h (3HEAD),
.BR feclearexcept (3M),
.BR fetestexcept (3M),
.BR isnan (3M),
.BR attributes (7),
.BR standards (7)
